==> client-java-api-4.0.0-sources.jar: io/kubernetes/client/models/V1ContainerStateWaitingFluentImpl.java <==
package io.kubernetes.client.models;

import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

public class V1ContainerStateWaitingFluentImpl<A extends V1ContainerStateWaitingFluent<A>> extends io.kubernetes.client.fluent.BaseFluent<A> implements V1ContainerStateWaitingFluent<A>{

    private String message;
    private String reason;

    public V1ContainerStateWaitingFluentImpl(){
    }
    public V1ContainerStateWaitingFluentImpl(V1ContainerStateWaiting instance){
            this.withMessage(instance.getMessage());

            this.withReason(instance.getReason());

    }

    public String getMessage(){
            return this.message;
    }

    public A withMessage(String message){
            this.message=message; return (A) this;
    }

    public Boolean hasMessage(){
            return this.message != null;
    }

    public String getReason(){
            return this.reason;
    }

    public A withReason(String reason){
            this.reason=reason; return (A) this;
    }

    public Boolean hasReason(){
            return this.reason != null;
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            V1ContainerStateWaitingFluentImpl that = (V1ContainerStateWaitingFluentImpl) o;
            if (message != null ? !message.equals(that.message) :that.message != null) return false;
            if (reason != null ? !reason.equals(that.reason) :that.reason != null) return false;
            return true;
    }




}

==> client-java-api-5.0.0-sources.jar: io/kubernetes/client/models/V1ContainerStateWaitingFluentImpl.java <==
package io.kubernetes.client.models;

import java.lang.StringBuffer;
import java.lang.StringBuilder;
import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

public class V1ContainerStateWaitingFluentImpl<A extends V1ContainerStateWaitingFluent<A>> extends io.kubernetes.client.fluent.BaseFluent<A> implements V1ContainerStateWaitingFluent<A>{

    private String message;
    private String reason;

    public V1ContainerStateWaitingFluentImpl(){
    }
    public V1ContainerStateWaitingFluentImpl(V1ContainerStateWaiting instance){
            this.withMessage(instance.getMessage());

            this.withReason(instance.getReason());

    }

    public String getMessage(){
            return this.message;
    }

    public A withMessage(String message){
            this.message=message; return (A) this;
    }

    public Boolean hasMessage(){
            return this.message != null;
    }

    public A withNewMessage(String arg1){
            return (A)withMessage(new String(arg1));
    }

    public A withNewMessage(StringBuilder arg1){
            return (A)withMessage(new String(arg1));
    }

    public A withNewMessage(StringBuffer arg1){
            return (A)withMessage(new String(arg1));
    }

    public String getReason(){
            return this.reason;
    }

    public A withReason(String reason){
            this.reason=reason; return (A) this;
    }

    public Boolean hasReason(){
            return this.reason != null;
    }

    public A withNewReason(String arg1){
            return (A)withReason(new String(arg1));
    }

    public A withNewReason(StringBuilder arg1){
            return (A)withReason(new String(arg1));
    }

    public A withNewReason(StringBuffer arg1){
            return (A)withReason(new String(arg1));
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            V1ContainerStateWaitingFluentImpl that = (V1ContainerStateWaitingFluentImpl) o;
            if (message != null ? !message.equals(that.message) :that.message != null) return false;
            if (reason != null ? !reason.equals(that.reason) :that.reason != null) return false;
            return true;
    }




}
